/*  setpriority - A simple commandline interface to the setpriority API

    Copyright 2004 Jonathan Overholt <jonathan@overholt.org>

    Licensed under the GPL.  See the file COPYING for the complete license

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#define VERSION    "0.1"

#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <errno.h>
#include <sys/resource.h>

int
main (int argc, char **argv)
{
  int nice;
  int i;
  int pid;
  int ret;
  char *errstr;

  if (argc < 3)
    {
      printf ("Usage: %s <priority> <pid> [<pid> [...]]\n", argv[0]);
      return 1;
    }

  nice = atoi (argv[1]);

  for (i = 2; i < argc; i++)
    {
      pid = atoi (argv[i]);

      /* Skip pids of 0, they were probably some text on the command line */
      if (pid == 0)
	continue;

      ret = setpriority (PRIO_PROCESS, pid, nice);

      if (ret == -1)
	{
	  switch (errno)
	    {
	    case EACCES:
	      errstr = "EACCES";
	      break;
	    case EINVAL:
	      errstr = "EINVAL";
	      break;
	    case ENOTSUP:
	      errstr = "ENOTSUP";
	      break;
	    case EPERM:
	      errstr = "EPERM";
	      break;
	    case ESRCH:
	      errstr = "ESRCH";
	      break;
	    }

	  fprintf (stderr,
		   "%s: could not set priority on pid %d, reason = %s(%d)\n",
		   argv[0], pid, errstr, errno);
	}
    }

  return 0;
}
